@@ -34,32 +34,6 @@ Sjis-JA - Source code filter to escape ShiftJIS (Japanese document)
       ? * găChJ[h̎w肪ł܂
       ' ` ' găNH[g邱Ƃł܂
 
-      g֐
-        Sjis::ord(...);
-        Sjis::reverse(...);
-        Sjis::length(...);
-        Sjis::substr(...);
-        Sjis::index(...);
-        Sjis::rindex(...);
-
-      Perl5.6 G~[V(perl5.005̏ꍇ)
-        use warnings;
-        use warnings::register;
-
-      ȉ̓_~[֐Ƃ
-        utf8::upgrade(...);
-        utf8::downgrade(...);
-        utf8::encode(...);
-        utf8::decode(...);
-        utf8::is_utf8(...);
-        utf8::valid(...);
-        bytes::chr(...);
-        bytes::index(...);
-        bytes::length(...);
-        bytes::ord(...);
-        bytes::rindex(...);
-        bytes::substr(...);
-
    g: B
 
     R}hvvgňȉ̂悤Ɏs
@@ -70,6 +44,32 @@ Sjis-JA - Source code filter to escape ShiftJIS (Japanese document)
       ShiftJIS_script.pl  --- ShiftJIS ŏꂽXNvg
       Escaped_script.pl.e --- GXP[vꂽXNvg
 
+   g֐
+      Sjis::ord(...);
+      Sjis::reverse(...);
+      Sjis::length(...);
+      Sjis::substr(...);
+      Sjis::index(...);
+      Sjis::rindex(...);
+
+   Perl5.6 G~[V(perl5.005̏ꍇ)
+      use warnings;
+      use warnings::register;
+
+   ȉ̓_~[֐Ƃ
+      utf8::upgrade(...);
+      utf8::downgrade(...);
+      utf8::encode(...);
+      utf8::decode(...);
+      utf8::is_utf8(...);
+      utf8::valid(...);
+      bytes::chr(...);
+      bytes::index(...);
+      bytes::length(...);
+      bytes::ord(...);
+      bytes::rindex(...);
+      bytes::substr(...);
+
 =head1 v
 
 ܂ł̗j͂߂܂傤BShiftJIS ̃T|[g jperl 4.019+1.3 n
@@ -317,10 +317,12 @@ l POSIX X^C̕NXĒ`Ă܂B
   [:digit:]     [\x30-\x39]
   [:graph:]     [\x21-\x7F]
   [:lower:]     [\x61-\x7A]
+                [\x41-\x5A\x61-\x7A]     (/i Cq)
   [:print:]     [\x20-\x7F]
   [:punct:]     [\x21-\x2F\x3A-\x3F\x40\x5B-\x5F\x60\x7B-\x7E]
   [:space:]     [\x09\x0A\x0B\x0C\x0D\x20]
   [:upper:]     [\x41-\x5A]
+                [\x41-\x5A\x61-\x7A]     (/i Cq)
   [:word:]      [\x30-\x39\x41-\x5A\x5F\x61-\x7A]
   [:xdigit:]    [\x30-\x39\x41-\x46\x61-\x66]
   [:^alnum:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39\x41-\x5A\x61-\x7A])
@@ -331,10 +333,12 @@ l POSIX X^C̕NXĒ`Ă܂B
   [:^digit:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39])
   [:^graph:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x21-\x7F])
   [:^lower:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x61-\x7A])
+                (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC])           (/i Cq)
   [:^print:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x20-\x7F])
   [:^punct:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x21-\x2F\x3A-\x3F\x40\x5B-\x5F\x60\x7B-\x7E])
   [:^space:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x09\x0A\x0B\x0C\x0D\x20])
   [:^upper:]    (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x41-\x5A])
+                (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC])           (/i Cq)
   [:^word:]     (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39\x41-\x5A\x5F\x61-\x7A])
   [:^xdigit:]   (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39\x41-\x46\x61-\x66])
   ---------------------------------------------------------------------------
@@ -478,16 +482,34 @@ perl5.00503 gpĂꍇłt@CeXgZq́uςݏd˂vƂ
 ẘ֐gꍇ͈ȉ̂悤ɋLqKv܂Bꂼ
 ̋@\ɂẮuẘ֐vQƂĂB
 
-  ---------------------------------
-  oCgw  w
-  ---------------------------------
-  ord         Sjis::ord
-  reverse     Sjis::reverse
-  length      Sjis::length
-  substr      Sjis::substr
-  index       Sjis::index
-  rindex      Sjis::rindex
-  ---------------------------------
+  ----------------------------------------------------
+  ֐    w        
+  ----------------------------------------------------
+  ord       Sjis::ord
+  reverse   Sjis::reverse
+  length    Sjis::length
+  substr    Sjis::substr
+  index     Sjis::index     ȉ̋LqQƂ̂
+  rindex    Sjis::rindex    ȉ̋LqQƂ̂
+  ----------------------------------------------------
+
+  index ̒Ԃ
+  --------------------------------------------------------------
+  ֐                  Ԓl         
+  --------------------------------------------------------------
+  index          w     oCgP   JPerlƓ
+  Sjis::index    w     P     w̓
+  CORE::index    oCgw   oCgP   oCgw̓
+  --------------------------------------------------------------
+
+  rindex ̒Ԃ
+  --------------------------------------------------------------
+  ֐                  Ԓl         
+  --------------------------------------------------------------
+  rindex         w     oCgP   JPerlƓ
+  Sjis::rindex   w     P     w̓
+  CORE::rindex   oCgw   oCgP   oCgw̓
+  --------------------------------------------------------------
 
 =head1 ẘ֐
 
@@ -1546,12 +1568,12 @@ zIɂ́Aȉ5̃S[悤ƍlĂ܂B
 
     JPerl  Perl 𕪊򂳂Ȃ悤ɂ邽߂ɁAC^v^𕪊򂳂܂B
     ł Perl RA`[̓C^v^̕]łȂ̂ł傤BʓIPerl
-    ꂪ򂵁AR~jeB͏k]VȂ܂B
+    ꂪ򂷂邱ƂɂȂAR~jeB͏k]VȂ܂B
 
     oCgw perl ͂łɃoCif[^Ƃł邽߁Aw
-    perl ʗĂō쐬Kv͂܂B̃\tgEFA͒PȂ Perl ̃Av
-    P[VvOłAtB^vOƂč쐬Ă܂B
-    {Iɂ perl słȂΓ삷ł傤B
+    perl ʗĂō쐬Kv͂܂B܂̃\tgEFÁAPȂAv
+    P[VvOȂ̂ŁAPerl RA`[ɂ܂邱ƂȂł傤A
+    USz܂B
 
     ɖ Perl XNvgŉ悤ƂȂAPerl R~jeB̃T|[g
     𓾂ł傤B
@@ -1591,6 +1613,16 @@ vO~O񋟂܂B
  ISBN 4-87311-097-1
  http://www.oreilly.co.jp/books/4873110971/
 
+ Programming Perl, 4th Edition
+ By: Tom Christiansen, brian d foy, Larry Wall, Jon Orwant
+ Publisher: O'Reilly Media
+ Formats: Print, Ebook, Safari Books Online
+ Released: February 2012
+ Pages: 1054
+ Print ISBN: 978-0-596-00492-7 | ISBN 10: 0-596-00492-3
+ Ebook ISBN: 978-1-4493-9890-3 | ISBN 10: 1-4493-9890-1
+ http://shop.oreilly.com/product/9780596004927.do
+
  PerlNbNubN 2 VOLUME 1
  By Tom Christiansen, Nathan Torkington, Shibuya Perl Mongers Ė, ЃhLgVXe 
  2004N09 s
